@@ -274,7 +274,11 @@ sub SetPropertyPath($$;$$$$)
     # set PropertyPath for all flattened tags of this structure if necessary
     # (note: don't do this for variable-namespace structures (undef NAMESPACE))
     my $strTable = $$tagInfo{Struct};
-    if ($strTable and $$strTable{NAMESPACE}) {
+    if ($strTable and $$strTable{NAMESPACE} and not ($parentID and
+        # must test NoSubStruct flag to avoid infinite recursion
+        (($$tagTablePtr{$parentID} and $$tagTablePtr{$parentID}{NoSubStruct}) or
+        length $parentID > 500))) # avoid deep recursion
+    {
         # make sure the structure namespace has been registered
         # (user-defined namespaces may not have been)
         RegisterNamespace($strTable) if ref $$strTable{NAMESPACE};
@@ -295,7 +299,7 @@ sub SetPropertyPath($$;$$$$)
         # (could happen if we were just writing a structure)
         unless ($tagInfo) {
             $tagInfo = { Name => ucfirst($flatID), Flat => 1 };
-            Image::ExifTool::AddTagToTable($tagTablePtr, $flatID, $tagInfo);
+            AddTagToTable($tagTablePtr, $flatID, $tagInfo);
         }
         # set StructType flag if any containing structure has a TYPE
         $$tagInfo{StructType} = 1 if $isType;
@@ -768,10 +772,16 @@ sub WriteXMP($$;$)
             # also allow for missing structure fields in lists of structures
             $regex =~  s/ \d+/ \\d\+/g;
             my $ok = $regex; # regular expression to match standard property names
+            my $ok2;
             # also check for incorrect list types which can cause problems
             if ($regex =~ s{\\/rdf\\:(Bag|Seq|Alt)\\/}{/rdf:(Bag|Seq|Alt)/}g) {
                 # also look for missing bottom-level list
                 $regex =~ s{/rdf:\(Bag\|Seq\|Alt\)\/rdf\\:li\\ \\d\+$}{(/.*)?};
+            } else {
+                $ok2 = $regex;
+                # check for properties in lists that shouldn't be
+                # (ref http://u88.n24.queensu.ca/exiftool/forum/index.php/topic,4325.0.html)
+                $regex .= '(/rdf:(Bag|Seq|Alt)/rdf:li \d+)?';
             }
             my @matches = sort grep m{^$regex$}i, keys %capture;
             if (@matches) {
@@ -804,6 +814,8 @@ sub WriteXMP($$;$)
                             my $fixed = shift @fixed;
                             $capture{$fixed} = $capture{$match};
                             delete $capture{$match};
+                            # remove xml:lang attribute from incorrect lang-alt list if necessary
+                            delete $capture{$fixed}[1]{'xml:lang'} if $ok2 and $match !~ /^$ok2$/;
                         }
                         $cap = $capture{$path} || $capture{$fixed[0]};
                         $exifTool->Warn("Fixed incorrect $wrn for $tg", 1);
@@ -977,10 +989,20 @@ sub WriteXMP($$;$)
                                            $path, $newValue, $$tagInfo{Struct});
             } else {
                 $newValue = EscapeXML($newValue);
-                if ($$tagInfo{Resource}) {
-                    $capture{$path} = [ '', { %attrs, 'rdf:resource' => $newValue } ];
-                } else {
+                for (;;) { # (a cheap 'goto')
+                    if ($$tagInfo{Resource}) {
+                        # only store as a resource if it doesn't contain any illegal characters
+                        if ($newValue !~ /[^a-z0-9\:\/\?\#\[\]\@\!\$\&\'\(\)\*\+\,\;\=\.\-\_\~]/i) {
+                            $capture{$path} = [ '', { %attrs, 'rdf:resource' => $newValue } ];
+                            last;
+                        }
+                        my $grp = $exifTool->GetGroup($tagInfo, 1);
+                        $exifTool->Warn("$grp:$$tagInfo{Name} written as a literal because value is not a valid URI", 1);
+                        # fall through to write as a string literal
+                    }
+                    delete $attrs{'rdf:resource'};  # (remove existing resource if necessary)
                     $capture{$path} = [ $newValue, \%attrs ];
+                    last;
                 }
                 if ($verbose > 1) {
                     my $grp = $exifTool->GetGroup($tagInfo, 1);
@@ -1279,7 +1301,7 @@ This file contains routines to write XMP metadata.
 
 =head1 AUTHOR
 
-Copyright 2003-2012, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2013, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
